# Conformance — `v1`

This directory contains golden vectors and rules for ARP Standard `v1` implementers.

- `json_vectors/` — valid payload fixtures (per-service)
- `json_vectors_invalid/` — invalid payload fixtures (negative cases)
- `rules/` — required endpoints and other conformance rules
